@@ -10,8 +10,7 @@ use rio_backend::clipboard::{Clipboard, ClipboardType};
 use rio_backend::config::colors::ColorRgb;
 use rio_window::application::ApplicationHandler;
 use rio_window::event::{
-    ElementState, Hook, Ime, MouseButton, MouseScrollDelta, StartCause, TouchPhase,
-    WindowEvent,
+    ElementState, Ime, MouseButton, MouseScrollDelta, StartCause, TouchPhase, WindowEvent,
 };
 use rio_window::event_loop::ActiveEventLoop;
 use rio_window::event_loop::ControlFlow;
@@ -155,27 +154,35 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
             RioEventType::Rio(RioEvent::RenderRoute(route_id)) => {
                 if self.config.renderer.strategy.is_event_based() {
                     if let Some(route) = self.router.routes.get_mut(&window_id) {
+                        // Skip rendering for unfocused windows if configured
                         if self.config.renderer.disable_unfocused_render
                             && !route.window.is_focused
                         {
                             return;
                         }
 
-                        // TODO: Optionally Allow check if is the current route
-                        // before schedule render. Using the following code below:
-                        // if route_id == route.window.screen.ctx().current_route() {
-                        let timer_id = TimerId::new(Topic::RenderRoute, route_id);
-                        let event = EventPayload::new(
-                            RioEventType::Rio(RioEvent::Render),
-                            window_id,
-                        );
+                        // Check if this is the current route
+                        if route_id == route.window.screen.ctx().current_route() {
+                            // Check if we need to throttle based on timing
+                            if let Some(wait_duration) = route.window.wait_until() {
+                                // We need to wait before rendering again
+                                let timer_id = TimerId::new(Topic::RenderRoute, route_id);
+                                let event = EventPayload::new(
+                                    RioEventType::Rio(RioEvent::Render),
+                                    window_id,
+                                );
 
-                        if !self.scheduler.scheduled(timer_id) {
-                            if let Some(limit) = route.window.wait_until() {
-                                route.window.start_render_timestamp();
-                                self.scheduler.schedule(event, limit, false, timer_id);
+                                // Only schedule if not already scheduled
+                                if !self.scheduler.scheduled(timer_id) {
+                                    self.scheduler.schedule(
+                                        event,
+                                        wait_duration,
+                                        false,
+                                        timer_id,
+                                    );
+                                }
                             } else {
-                                route.window.start_render_timestamp();
+                                // We can render immediately
                                 route.request_redraw();
                             }
                         }
@@ -198,28 +205,6 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                     );
                 }
             }
-            RioEventType::Rio(RioEvent::UpdateGraphicLibrary) => {
-                if let Some(route) = self.router.routes.get_mut(&window_id) {
-                    let mut terminal = route
-                        .window
-                        .screen
-                        .context_manager
-                        .current_mut()
-                        .terminal
-                        .lock();
-                    let graphics = terminal.graphics_take_queues();
-                    drop(terminal);
-                    if let Some(graphic_queues) = graphics {
-                        for graphic_data in graphic_queues.pending {
-                            route.window.screen.sugarloaf.graphics.insert(graphic_data);
-                        }
-
-                        for graphic_data in graphic_queues.remove_queue {
-                            route.window.screen.sugarloaf.graphics.remove(&graphic_data);
-                        }
-                    }
-                }
-            }
             RioEventType::Rio(RioEvent::ReportToAssistant(error)) => {
                 if let Some(route) = self.router.routes.get_mut(&window_id) {
                     route.report_error(&error);
@@ -1123,8 +1108,11 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
             }
 
             WindowEvent::RedrawRequested => {
+                // let start = std::time::Instant::now();
                 route.window.winit_window.pre_present_notify();
 
+                route.begin_render();
+
                 match route.path {
                     RoutePath::Assistant => {
                         route.window.screen.render_assistant(&route.assistant);
@@ -1136,20 +1124,20 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
                         route.window.screen.render();
                     }
                     RoutePath::ConfirmQuit => {
-                        route
-                            .window
-                            .screen
-                            .render_dialog("Do you want to leave Rio?");
+                        route.window.screen.render_dialog(
+                            "Quit Rio?",
+                            "Continue -> press escape key",
+                            "Quit -> press enter key",
+                        );
                     }
                 }
+
+                // let duration = start.elapsed();
                 // println!("Time elapsed in render() is: {:?}", duration);
                 // }
 
-                if self.config.renderer.strategy.is_continuous()
-                    && !self.config.renderer.disable_unfocused_render
-                    && route.window.is_focused
-                {
-                    route.request_frame(&mut self.scheduler);
+                if self.config.renderer.strategy.is_game() {
+                    route.request_redraw();
                 }
 
                 event_loop.set_control_flow(ControlFlow::Wait);
@@ -1181,7 +1169,12 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
         }
     }
 
-    fn hook_event(&mut self, _event_loop: &ActiveEventLoop, hook: &Hook) {
+    fn hook_event(
+        &mut self,
+        _event_loop: &ActiveEventLoop,
+        key: &rio_window::event::KeyEvent,
+        modifiers: &rio_window::event::Modifiers,
+    ) {
         let window_id = match self.router.get_focused_route() {
             Some(window_id) => window_id,
             None => return,
@@ -1192,38 +1185,18 @@ impl ApplicationHandler<EventPayload> for Application<'_> {
             None => return,
         };
 
-        match hook {
-            Hook::Copy => {
-                route.window.screen.copy_selection(ClipboardType::Clipboard);
-            }
-            Hook::Paste => {
-                let content = route
-                    .window
-                    .screen
-                    .clipboard
-                    .borrow_mut()
-                    .get(ClipboardType::Selection);
-                route.window.screen.paste(&content, true);
-            }
-            Hook::CreateTab => {
-                if self.config.navigation.has_navigation_key_bindings() {
-                    route.window.screen.create_tab();
-                }
-            }
-            Hook::Close => {
-                route.window.screen.close_split_or_tab();
-            }
-            Hook::SplitDown => {
-                if self.config.navigation.use_split {
-                    route.window.screen.split_down();
-                }
-            }
-            Hook::SplitRight => {
-                if self.config.navigation.use_split {
-                    route.window.screen.split_right();
-                }
-            }
-        }
+        // For menu-triggered events, we need to temporarily set the correct modifiers
+        // since menu events don't trigger ModifiersChanged events.
+        let original_modifiers = route.window.screen.modifiers;
+
+        // Use the modifiers passed from the menu action
+        route.window.screen.set_modifiers(*modifiers);
+
+        // Process the key event
+        route.window.screen.process_key_event(&key);
+
+        // Restore the original modifiers
+        route.window.screen.set_modifiers(original_modifiers);
     }
 
     // Emitted when the event loop is being shut down.
