@@ -11,7 +11,7 @@
 
 use crate::font_introspector::{GlyphId, NormalizedCoord};
 use crate::layout::FragmentStyleDecoration;
-use crate::sugarloaf::primitives::SugarCursor;
+use crate::sugarloaf::primitives::{DrawableChar, SugarCursor};
 
 /// Properties for a text run.
 #[derive(Copy, Clone)]
@@ -30,6 +30,10 @@ pub struct TextRunStyle<'a> {
     pub topline: f32,
     /// Absolute line height of the run.
     pub line_height: f32,
+    /// Padding y
+    pub padding_y: f32,
+    /// Absolute line height of the run without mod.
+    pub line_height_without_mod: f32,
     /// Total advance of the run.
     pub advance: f32,
     /// Underline style.
@@ -38,6 +42,7 @@ pub struct TextRunStyle<'a> {
     pub decoration_color: Option<[f32; 4]>,
     /// Cursor style.
     pub cursor: Option<SugarCursor>,
+    pub drawable_char: Option<DrawableChar>,
 }
 
 /// Positioned glyph in a text run.
